//
//  ISInternet.h
//  Coffee
//
//  Created by Piero Avola on 24.08.08.
//  Copyright 2008 inventiveSoft. All rights reserved.
//

#import <Cocoa/Cocoa.h>


@interface ISInternet : NSObject {

}

/*!
    @class ISInternet
    @abstract    Diese Klasse kommuniziert mit dem Internet.
    @discussion  Kommunikation mit dem Internet wird durch diese Klasse vereinfacht.
    @availability 1.0 und höher.
*/


/*+(BOOL)mailFrom:(NSString *)from to:(NSString *)to subject:(NSString *)subject text:(NSString *)text;*/

/*!
    @method     +dataForPOST:
    @discussion Diese Methode generiert einen HTTP Header mit den Werten aus einem NSDictionary.
    @param dict NSDictionary mit NSString Objekten als Key und NSString oder NSURL (als Pfad zu einer Datei, die hochgeldaen wird) als Value.
    @result Gibt ein NSData Objekt zurück. (ASCII encoded).
    @availability 1.0 und höher.
*/


+(NSData *)dataForPOST:(NSDictionary *)dict;

/*!
    @method     dataForPOST:withEncoding:
    @discussion Diese Methode generiert einen HTTP Header mit den Werten aus einem NSDictionary.
    @param dict NSDictionary mit NSString Objekten als Key und NSString oder NSURL (als Pfad zu einer Datei, die hochgeldaen wird) als Value.
    @param encoding Gibt das Encoding an, das genutzt wird, um Das NSData Objekt zu erstellen.
    @availability 1.0 und höher.
*/

+(NSData *)dataForPOST:(NSDictionary *)dict withEncoding:(NSStringEncoding)encoding;

/*!
    @method     postRequestWithURL:dictionary:
    @discussion Führt einen einfachen POST-Request mit gegebener URL und Schlüssel-Werte-Paaren aus. Es können keine Dateien hochgeladen werden.
    @param url NSURL Objekt an das der Request gerichtet wird.
    @param dict NSDictionary mit NSStrings als Key und Value.
    @result Die Antort des Servers als NSData Objekt.
    @availability 1.0 und höher.
*/


+(NSData *)postRequestWithURL:(NSURL *)url dictionary:(NSDictionary *)dict;

/*!
    @function ConnectivityApproved
    @discussion Gibt an, ob eine Verbindung zum Internet besteht.
    @result     YES, wenn eine Verbindung zum Internet besteht, andernfalls NO.
    @availability 1.0 und höher.
*/

BOOL ConnectivityApproved(void);

@end
